
#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer dax__create_buffer
#define yy_delete_buffer dax__delete_buffer
#define yy_scan_buffer dax__scan_buffer
#define yy_scan_string dax__scan_string
#define yy_scan_bytes dax__scan_bytes
#define yy_init_buffer dax__init_buffer
#define yy_flush_buffer dax__flush_buffer
#define yy_load_buffer_state dax__load_buffer_state
#define yy_switch_to_buffer dax__switch_to_buffer
#define yypush_buffer_state dax_push_buffer_state
#define yypop_buffer_state dax_pop_buffer_state
#define yyensure_buffer_stack dax_ensure_buffer_stack
#define yy_flex_debug dax__flex_debug
#define yyin dax_in
#define yyleng dax_leng
#define yylex dax_lex
#define yylineno dax_lineno
#define yyout dax_out
#define yyrestart dax_restart
#define yytext dax_text
#define yywrap dax_wrap
#define yyalloc dax_alloc
#define yyrealloc dax_realloc
#define yyfree dax_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define dax__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer dax__create_buffer
#endif

#ifdef yy_delete_buffer
#define dax__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer dax__delete_buffer
#endif

#ifdef yy_scan_buffer
#define dax__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer dax__scan_buffer
#endif

#ifdef yy_scan_string
#define dax__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string dax__scan_string
#endif

#ifdef yy_scan_bytes
#define dax__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes dax__scan_bytes
#endif

#ifdef yy_init_buffer
#define dax__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer dax__init_buffer
#endif

#ifdef yy_flush_buffer
#define dax__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer dax__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define dax__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state dax__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define dax__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer dax__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define dax_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state dax_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define dax_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state dax_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define dax_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack dax_ensure_buffer_stack
#endif

#ifdef yylex
#define dax_lex_ALREADY_DEFINED
#else
#define yylex dax_lex
#endif

#ifdef yyrestart
#define dax_restart_ALREADY_DEFINED
#else
#define yyrestart dax_restart
#endif

#ifdef yylex_init
#define dax_lex_init_ALREADY_DEFINED
#else
#define yylex_init dax_lex_init
#endif

#ifdef yylex_init_extra
#define dax_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra dax_lex_init_extra
#endif

#ifdef yylex_destroy
#define dax_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy dax_lex_destroy
#endif

#ifdef yyget_debug
#define dax_get_debug_ALREADY_DEFINED
#else
#define yyget_debug dax_get_debug
#endif

#ifdef yyset_debug
#define dax_set_debug_ALREADY_DEFINED
#else
#define yyset_debug dax_set_debug
#endif

#ifdef yyget_extra
#define dax_get_extra_ALREADY_DEFINED
#else
#define yyget_extra dax_get_extra
#endif

#ifdef yyset_extra
#define dax_set_extra_ALREADY_DEFINED
#else
#define yyset_extra dax_set_extra
#endif

#ifdef yyget_in
#define dax_get_in_ALREADY_DEFINED
#else
#define yyget_in dax_get_in
#endif

#ifdef yyset_in
#define dax_set_in_ALREADY_DEFINED
#else
#define yyset_in dax_set_in
#endif

#ifdef yyget_out
#define dax_get_out_ALREADY_DEFINED
#else
#define yyget_out dax_get_out
#endif

#ifdef yyset_out
#define dax_set_out_ALREADY_DEFINED
#else
#define yyset_out dax_set_out
#endif

#ifdef yyget_leng
#define dax_get_leng_ALREADY_DEFINED
#else
#define yyget_leng dax_get_leng
#endif

#ifdef yyget_text
#define dax_get_text_ALREADY_DEFINED
#else
#define yyget_text dax_get_text
#endif

#ifdef yyget_lineno
#define dax_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno dax_get_lineno
#endif

#ifdef yyset_lineno
#define dax_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno dax_set_lineno
#endif

#ifdef yywrap
#define dax_wrap_ALREADY_DEFINED
#else
#define yywrap dax_wrap
#endif

#ifdef yyalloc
#define dax_alloc_ALREADY_DEFINED
#else
#define yyalloc dax_alloc
#endif

#ifdef yyrealloc
#define dax_realloc_ALREADY_DEFINED
#else
#define yyrealloc dax_realloc
#endif

#ifdef yyfree
#define dax_free_ALREADY_DEFINED
#else
#define yyfree dax_free
#endif

#ifdef yytext
#define dax_text_ALREADY_DEFINED
#else
#define yytext dax_text
#endif

#ifdef yyleng
#define dax_leng_ALREADY_DEFINED
#else
#define yyleng dax_leng
#endif

#ifdef yyin
#define dax_in_ALREADY_DEFINED
#else
#define yyin dax_in
#endif

#ifdef yyout
#define dax_out_ALREADY_DEFINED
#else
#define yyout dax_out
#endif

#ifdef yy_flex_debug
#define dax__flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug dax__flex_debug
#endif

#ifdef yylineno
#define dax_lineno_ALREADY_DEFINED
#else
#define yylineno dax_lineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define dax_wrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 140
#define YY_END_OF_BUFFER 141
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[775] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  141,  139,   15,   10,
       10,   15,   15,  119,   10,  119,    5,    6,    5,    8,
        9,    8,  135,  127,  128,  136,  133,  136,  134,  138,
      127,  128,  138,  139,   40,   10,   40,   40,   40,   38,

       40,   40,   40,   40,   40,   40,   40,   44,   10,   44,
       44,  139,  139,   44,   51,   10,   51,   51,   51,   49,
       51,   55,   10,   55,  139,   55,   72,   10,   72,   72,
       72,   70,   72,   72,   72,   72,   72,   76,   10,   76,
      139,   76,   83,   10,   83,   83,   83,   81,   83,   87,
       10,   87,  114,   10,  114,  114,  114,  112,  114,  114,
      114,  114,  114,  114,  118,   10,  118,  136,  135,   10,
        0,    2,    2,    0,    4,    7,  130,  129,    0,    0,
        0,    0,    0,    0,    0,   39,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   41,    0,    0,    0,    0,

        0,    0,    0,    0,   50,   52,   52,    0,    0,   71,
       73,   73,   73,   73,   73,   73,    0,    0,   82,   84,
       84,    0,  113,  115,  115,  115,  115,  115,  115,  115,
      115,    0,    0,    0,    0,    0,    0,    0,    3,    0,
        0,    0,    0,    0,    0,    0,  137,    0,   41,   41,
       41,   41,   41,   41,   41,   41,   41,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   52,    0,    0,    0,
        0,    0,   73,   73,   73,   73,    0,    0,    0,   84,
        0,    0,  115,  115,  115,  115,  115,  115,  115,    0,
        0,    0,  132,    0,   14,    1,    0,    0,  125,    0,

        0,    0,  122,  121,    0,    0,   41,   41,   41,   41,
       41,   41,   41,   41,   41,    0,    0,   43,    0,    0,
        0,   57,    0,    0,   56,    0,    0,    0,    0,    0,
       54,    0,    0,    0,   59,   58,   73,   73,   73,   73,
        0,    0,   75,    0,    0,    0,    0,    0,    0,   86,
        0,  115,  115,  115,  115,  115,  115,  115,    0,    0,
      117,    0,    0,    0,    0,  126,  120,    0,    0,   17,
       41,   41,   41,   41,   41,    0,    0,   41,   41,   41,
        0,   16,    0,   57,    0,   88,   56,    0,    0,   48,
       47,    0,    0,   73,    0,    0,   73,   73,   73,    0,

       89,    0,   80,   79,    0,    0,    0,    0,    0,  115,
      115,    0,    0,  115,    0,    0,    0,    0,    0,    0,
        0,   12,    0,  123,  124,   17,   41,    0,    0,   41,
        0,    0,   41,    0,   29,   28,   41,    0,   41,    0,
       41,    0,   16,   46,    0,   88,   45,    0,    0,    0,
        0,    0,   63,   62,   73,   73,   73,    0,   74,   89,
        0,    0,   91,   90,    0,    0,    0,  115,  115,    0,
      105,  104,  115,    0,  111,  110,    0,    0,    0,    0,
        0,   11,   41,    0,   21,   20,   41,    0,   25,   24,
       41,   41,   41,    0,   33,   32,   41,    0,   42,   46,

       77,   45,    0,   78,    0,   61,   60,   73,   73,   73,
        0,    0,    0,    0,    0,  115,  115,  115,    0,  116,
        0,    0,    0,    0,   41,   41,   41,    0,    0,   41,
       41,   77,    0,   53,   78,   73,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  115,  115,  115,    0,    0,
        0,    0,   41,   41,    0,    0,    0,   31,   30,   41,
       41,   73,    0,   67,   66,    0,   69,   68,    0,   85,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      131,    0,    0,    0,   41,    0,    0,    0,   27,   26,
        0,    0,   41,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   23,   22,    0,   35,   34,   41,
        0,   65,   64,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   19,   18,   41,   93,    0,   92,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   41,   95,   94,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   41,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,   41,    0,   99,    0,   98,    0,  103,
        0,  102,    0,  109,    0,  108,    0,    0,    0,    0,
        0,    0,   41,   97,   96,  101,  100,  107,  106,    0,
        0,    0,   12,    0,   12,    0,   41,    0,    0,    0,
        0,    0,   41,    0,    0,    0,    0,    0,   11,    0,
       37,   36,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   13,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    1,    1,    8,    9,    1,
        1,    1,    1,    1,   10,   11,   12,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   14,   15,   16,
       17,   18,   19,    1,   20,   21,   22,   23,   24,   21,
       25,   25,   25,   25,   25,   26,   27,   25,   28,   29,
       25,   25,   30,   31,   25,   25,   25,   25,   32,   25,
       33,    1,   34,    1,   25,    1,   35,   36,   37,   38,

       39,   40,   41,   42,   43,   44,   45,   46,   47,   48,
       49,   50,   51,   52,   53,   54,   55,   56,   25,   57,
       58,   59,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[60] =
    {   0,
        1,    2,    2,    2,    1,    1,    1,    1,    1,    3,
        3,    1,    4,    5,    1,    1,    1,    6,    1,    7,
        7,    7,    7,    7,    5,    5,    5,    5,    5,    5,
        5,    5,    1,    1,    7,    7,    7,    7,    7,    7,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5
    } ;

static const flex_int16_t yy_base[814] =
    {   0,
        0,    0,    0,    3,    6,    9,   24,   27,   11,   14,
       15,   17,   29,   38,   45,   52,   59,   61,   67,   70,
       95,    0,   73,   76,  153,  156,  159,  162,  177,  180,
      183,  186,  201,  204,  207,  210,  226,  278,  245,  248,
      251,  254,  297,  300,  303,  306,  330,    0,  388,  391,
      394,  397,  412,  415,  418,  421,  437,  489,  456,  459,
      541,    0,  462,  465,  598,  600, 2053, 2135, 2135,  269,
      272,   47,   62, 2135,  321,  172, 2135, 2135, 2033, 2135,
     2135, 2022, 2135, 2033, 2031,  475, 2135, 2135, 2135, 2135,
     2027, 2025, 1987,  468, 2135,  324, 1998,    0,  196, 2135,

        8, 1968, 1958, 1952, 1863, 1858,   35, 2135,  481,  600,
      608,  604,  612,  641, 2135,  509, 1878,    0,  258, 2135,
     1855, 2135,  515,  660,  663,  682, 2135,  525, 1875,    0,
      310, 2135, 1854, 1852, 1855, 1834, 1849, 2135,  528,  704,
      701,  723, 2135,  531, 1869,    0,  407, 2135, 1847, 2135,
      534,  606, 2135,  626, 1857,    0,  469, 2135, 1831, 1829,
     1821, 1830, 1814,   32, 2135,  667,  621, 1851, 1820,  671,
      628, 1784, 2135, 1827, 1818, 2135, 2135, 2135,    2,   44,
     1781, 1780, 1778, 1814, 1793, 2135,    0, 1787, 1774, 1777,
     1784, 1784, 1772, 1747, 1752, 1753, 1752, 1748, 1742, 1722,

     1735, 1712, 1715, 1720, 2135,    0, 1713, 1695, 1693, 2135,
        0,  686, 1670, 1671, 1668, 1660, 1666, 1656, 2135,    0,
     1661, 1650, 2135,    0, 1652, 1644, 1635, 1646, 1627, 1648,
     1632, 1626, 1634, 1648, 1646, 1649,  458, 1611, 2135,   72,
        0, 1606, 1602, 1635, 1633, 1594, 2135, 1607, 1590, 1586,
     1594, 1592, 1601, 1583, 1567, 1567, 1600,  759,  762, 1577,
     1564, 1570, 1547, 1559, 1560, 1544,  727,  766,  772, 1534,
      779,  783, 1545, 1536, 1520, 1519,  791,  795, 1528,  799,
      802,  808, 1527, 1517, 1517, 1513, 1506, 1496, 1503,  815,
      819, 1519, 2135, 1521, 2135, 2135,   17, 1488, 2135, 1514,

     1513, 1473, 2135, 2135, 1464, 1475, 1477, 1459, 1490, 1453,
     1450,  825, 1455, 1443, 1438,  828,  832, 2135,  836, 1449,
     1442,  845, 1447, 1432,  849, 1437,  853,  856,  864,  871,
     2135,  874, 1433,  877, 2135, 2135, 1425,  891, 1426, 1421,
      894,  897, 2135,  900, 1410,  903,  907,  919,  922, 2135,
      925,  928,  931, 1411, 1406,  947, 1404,  950,  953,  956,
     2135,  966, 1422,  646,  976, 2135, 2135, 1429, 1427,  959,
     1419,  979, 1386,  983, 1379,  986,  995, 1374, 1004, 1381,
     1007,  989, 1379, 1010, 1367, 1013, 1020, 1369, 1024, 2135,
     2135, 1032, 1357, 1035, 1038, 1054, 1352, 1353, 1347, 1041,

     1062, 1065, 2135, 2135, 1073, 1077, 1080, 1093, 1096, 1333,
     1325, 1104, 1111, 1334, 1120, 1123, 1131, 1352,  507, 1353,
     1136, 2135, 1347, 2135, 2135, 1139, 1315, 1142, 1149, 1291,
     1159, 1162, 1297, 1176, 2135, 2135, 1295, 1170, 1285, 1187,
     1298, 1195, 1198, 1201, 1275, 1204, 1207, 1212, 1274, 1215,
     1218, 1231, 2135, 2135, 1282, 1273, 1263, 1239, 2135, 1242,
     1245, 1249, 2135, 2135, 1258,  124,  125, 1274, 1262, 1266,
     2135, 2135, 1259, 1274, 2135, 2135, 1282, 1261,  491,  152,
        5, 2135, 1235, 1285, 2135, 2135, 1234, 1293, 2135, 2135,
     1227, 1301, 1226, 1304, 2135, 2135, 1235, 1312, 2135, 1317,

     1320, 1323, 1329, 1332, 1335, 2135, 2135, 1236, 1346, 1349,
     1352, 1223, 1211, 1217, 1204, 1210, 1202, 1187, 1355, 2135,
     1218,  174,  158,  384, 1188, 1177, 1358, 1365, 1374, 1186,
     1181, 1382, 1385, 2135, 1388, 1187, 1391, 1395, 1407, 1410,
     1418, 1175, 1169, 1162, 1141, 1423, 1426, 1429, 1161, 1435,
      176,  461, 1134, 1445, 1448, 1452, 1464, 2135, 2135, 1472,
     1151, 1475, 1478, 2135, 2135, 1491, 2135, 2135, 1499, 2135,
     1128, 1131, 1122, 1120, 1502, 1505, 1518, 1521, 1529, 1534,
     2135, 1545,  228,  179, 1548, 1551, 1555, 1567, 2135, 2135,
     1575, 1579, 1143, 1587, 1591, 1113, 1105, 1103, 1101, 1599,

      567,  570, 1607,  582,  626, 1615,  668,  671,  280,  222,
      643, 1623, 1626, 1635, 2135, 2135, 1643, 2135, 2135, 1101,
     1651, 2135, 2135, 1142, 1093, 1127, 1077, 1095, 1076, 1084,
     1066, 1081, 1059, 1074, 1052, 1068, 1049, 1058, 1040,  715,
      244,  385, 1659, 2135, 2135, 1053, 2135, 1082, 2135, 1078,
     1026, 1015, 1016, 1006, 1008,  992, 1000,  974,  973,  921,
      929,  918,  388,  391, 1667,  937, 2135, 2135,  912,  907,
      889,  902,  861,  851,  835,  848,  832,  830,  792,  776,
     1670, 1673, 1676, 1693,  753,  714,  746,  695,  712,  666,
      678,  644,  648,  603,  609,  501,  471, 1701, 1704, 1711,

     1721, 1739, 1773,  408,  429, 2135,  421, 2135,  421, 2135,
      402, 2135,  402, 2135,  396, 2135,  725, 1791,  675,  506,
     1809, 1843,  272, 2135, 2135, 2135, 2135, 2135, 2135,  684,
      706,  200,  311,  731,  260, 1731,  220,  668,  218,  202,
      207, 1765, 1836,  296,  153, 1861, 1757,  728, 2135, 1799,
     2135, 2135, 1734, 1864,  439,  709,  753,  773,  806,  807,
      761,  873,  823,  901,  948, 1031, 1013, 1035, 1014,  929,
     1877, 1881, 2135, 2135, 1899, 1906, 1913, 1920, 1927, 1934,
     1941, 1948, 1955, 1962, 1969, 1976, 1983, 1990, 1995, 2000,
     2005, 2010, 2015, 2022, 2025, 2028, 2031, 2034, 2037, 2044,

     2048, 2054, 2060, 2066, 2072, 2078, 2085, 2092, 2099, 2106,
     2113, 2120, 2127
    } ;

static const flex_int16_t yy_def[814] =
    {   0,
      775,  775,  776,  776,  776,  776,  777,  777,  778,  778,
      779,  779,  780,  780,  780,  780,  781,  781,  775,  775,
      774,   21,  782,  782,  782,  782,  775,  775,  782,  782,
      775,  775,  782,  782,  782,  782,  783,  783,  784,  784,
      775,  775,  784,  784,  784,  784,  774,   47,  785,  785,
      775,  775,  785,  785,  785,  785,  786,  786,  787,  787,
      774,   61,  788,  788,  780,  780,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  789,  774,  774,

      789,  789,  789,  789,  789,  789,  789,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  790,  774,  774,
      790,  774,  774,  774,  774,  774,  774,  774,  774,  791,
      774,  774,  791,  791,  791,  791,  791,  774,  774,  774,
      774,  774,  774,  774,  774,  792,  774,  774,  792,  774,
      774,  774,  774,  774,  774,  793,  774,  774,  793,  793,
      793,  793,  793,  793,  774,  774,  774,  774,  774,  774,
      794,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  789,  789,  789,  789,
      789,  789,  789,  789,  789,  789,  795,  774,  774,  774,

      774,  774,  774,  774,  774,  790,  790,  796,  774,  774,
      791,  791,  791,  791,  791,  791,  797,  774,  774,  792,
      792,  798,  774,  793,  793,  793,  793,  793,  793,  793,
      793,  799,  774,  774,  800,  774,  800,  774,  774,  774,
      801,  774,  774,  774,  774,  774,  774,  774,  789,  789,
      789,  789,  789,  789,  789,  789,  789,  802,  802,  774,
      774,  774,  774,  774,  774,  774,  790,  803,  803,  774,
      774,  774,  791,  791,  791,  791,  804,  804,  774,  792,
      805,  805,  793,  793,  793,  793,  793,  793,  793,  806,
      806,  774,  774,  800,  774,  774,  800,  774,  774,  801,

      774,  774,  774,  774,  774,  774,  789,  789,  789,  789,
      789,  789,  789,  789,  789,  774,  802,  774,  802,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  803,
      774,  803,  774,  774,  774,  774,  791,  791,  791,  791,
      774,  804,  774,  804,  774,  774,  774,  774,  805,  774,
      805,  793,  793,  793,  793,  793,  793,  793,  774,  806,
      774,  806,  774,  800,  807,  774,  774,  774,  774,  774,
      789,  789,  789,  789,  789,  774,  774,  789,  789,  789,
      802,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  803,  774,  791,  774,  774,  791,  791,  791,  804,

      774,  774,  774,  774,  805,  774,  774,  774,  774,  793,
      793,  774,  774,  793,  774,  774,  806,  774,  800,  807,
      807,  774,  807,  774,  774,  774,  789,  774,  774,  789,
      774,  774,  789,  774,  774,  774,  789,  774,  789,  774,
      789,  802,  774,  774,  774,  774,  774,  803,  774,  774,
      774,  774,  774,  774,  791,  791,  791,  774,  774,  774,
      805,  774,  774,  774,  774,  774,  774,  793,  793,  774,
      774,  774,  793,  774,  774,  774,  806,  774,  800,  807,
      807,  774,  789,  774,  774,  774,  789,  774,  774,  774,
      789,  789,  789,  774,  774,  774,  789,  774,  774,  774,

      774,  774,  803,  774,  774,  774,  774,  791,  791,  791,
      805,  774,  774,  774,  774,  793,  793,  793,  774,  774,
      774,  800,  807,  807,  789,  789,  789,  774,  774,  789,
      789,  774,  774,  774,  774,  791,  774,  774,  774,  774,
      805,  774,  774,  774,  774,  793,  793,  793,  774,  800,
      807,  807,  789,  789,  774,  774,  774,  774,  774,  789,
      789,  791,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  800,  807,  807,  789,  774,  774,  774,  774,  774,
      774,  774,  789,  774,  774,  774,  774,  774,  774,  774,

      774,  774,  774,  774,  774,  774,  774,  774,  800,  807,
      807,  774,  774,  774,  774,  774,  774,  774,  774,  789,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  800,
      807,  807,  774,  774,  774,  789,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  800,  807,  807,  789,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      800,  807,  807,  807,  789,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  800,  807,  807,

      807,  808,  809,  789,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  800,  807,  810,  811,
      808,  809,  789,  774,  774,  774,  774,  774,  774,  800,
      810,  807,  812,  811,  813,  807,  789,  800,  812,  774,
      813,  807,  789,  800,  774,  774,  774,  800,  774,  774,
      774,  774,  800,  800,  800,  800,  800,  800,  800,  800,
      800,  800,  800,  800,  800,  800,  800,  800,  800,  800,
      800,  800,  774,    0,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,

      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774
    } ;

static const flex_int16_t yy_nxt[2195] =
    {   0,
      774,   70,   71,   70,   70,   71,   70,   70,   71,   70,
       70,   71,   70,   78,  240,   72,   78,   81,   72,   81,
       79,   73,  422,   79,   73,   75,   71,   75,   75,   71,
       75,   84,   85,   82,  295,   82,   86,   87,  364,   76,
       84,   85,   76,  524,   88,   86,   87,   84,   85,  188,
       89,  171,   86,   88,   84,   85,  189,   89,  241,   86,
       88,   91,   92,   91,   92,  172,  171,   88,   71,   71,
       71,   71,   71,   71,  109,   71,  109,  109,   71,  109,
      173,  195,   94,  230,  240,   94,  299,  196,  110,  231,
      242,  110,   93,  243,   93,   95,   96,   71,   96,   95,

       95,   95,   95,   95,   95,   95,   97,   95,   98,   95,
       99,   95,  100,   95,   98,   98,   98,   98,   98,   98,
       98,   98,   98,   98,   98,   98,   98,   95,   95,   98,
       98,  101,   98,   98,  102,   98,   98,  103,  104,   98,
       98,   98,  105,   98,   98,   98,   98,   98,   98,   98,
      106,  107,   98,   98,  109,   71,  109,  109,   71,  109,
       71,   71,   71,   71,   71,   71,  512,  514,  111,  422,
      749,  111,  513,  515,  112,  422,  174,  112,  109,   71,
      109,  109,   71,  109,   71,   71,   71,   71,   71,   71,
      173,  295,  110,  422,  551,  110,  422,  550,  113,  523,

      174,  113,  109,   71,  109,  109,   71,  109,  109,   71,
      109,  109,   71,  109,  173,  740,  111,  422,  423,  111,
      745,  611,  114,  740,  583,  114,  115,  116,   71,  116,
      115,  115,  115,  115,  115,  115,  115,  117,  115,  422,
      115,  119,  115,  120,  115,  422,  123,   71,  123,  123,
       71,  123,   71,   71,   71,   71,   71,   71,  115,  115,
      124,  422,  174,  124,  641,  610,  125,  743,  740,  125,
      170,  170,  170,  170,  170,  170,  173,  121,  115,  116,
       71,  116,  115,  115,  115,  115,  115,  115,  115,  117,
      115,  664,  115,  119,  115,  120,  115,  295,  123,   71,

      123,  123,   71,  123,  123,   71,  123,  123,   71,  123,
      115,  115,  124,  295,  174,  124,  740,  640,  126,  748,
      737,  126,  170,  170,  170,  170,  170,  170,  173,  121,
      127,  128,   71,  128,  127,  127,  127,  127,  127,  127,
      127,  129,  127,  130,  127,  131,  127,  132,  127,  130,
      130,  130,  130,  130,  130,  130,  130,  130,  130,  130,
      130,  130,  127,  127,  130,  130,  130,  130,  130,  130,
      130,  130,  133,  130,  130,  134,  130,  135,  130,  130,
      130,  136,  130,  130,  130,  137,  130,  130,  130,  139,
       71,  139,  139,   71,  139,   71,   71,   71,   71,   71,

       71,  422,  422,  140,  729,  295,  140,  728,  422,  141,
      727,  174,  141,  139,   71,  139,  139,   71,  139,  139,
       71,  139,  139,   71,  139,  173,  726,  140,  681,  725,
      140,  682,  665,  142,  724,  552,  142,  143,  144,   71,
      144,  143,  143,  143,  143,  143,  143,  143,  145,  143,
      723,  143,  147,  143,  148,  143,  295,  151,   71,  151,
      151,   71,  151,  166,   71,  166,  166,   71,  166,  143,
      143,  152,  174,  174,  152,  295,  757,  167,  422,  716,
      167,  179,  170,  170,  170,  297,  173,  173,  149,  143,
      144,   71,  144,  143,  143,  143,  143,  143,  143,  143,

      145,  143,  185,  143,  147,  143,  148,  143,  295,  180,
      170,  170,  170,  584,  732,  181,  170,  170,  170,  522,
      182,  143,  143,  735,  295,  183,  170,  170,  170,  170,
      170,  170,  170,  170,  170,  170,  170,  170,  479,  715,
      149,  153,  154,   71,  154,  153,  153,  153,  153,  153,
      153,  153,  155,  153,  156,  153,  157,  153,  158,  153,
      156,  156,  156,  156,  156,  156,  156,  156,  156,  156,
      156,  156,  156,  153,  153,  156,  156,  156,  156,  156,
      159,  156,  156,  156,  156,  156,  160,  156,  156,  161,
      156,  156,  162,  163,  164,  156,  156,  156,  156,  156,

       84,   85,   84,   85,  174,   86,  628,   86,  174,  630,
      174,  197,  174,  168,  714,  168,  174,  222,  173,  197,
      629,  632,  173,  631,  173,  174,  173,  170,  170,  170,
      173,  169,  232,  169,  198,  633,  199,  236,  198,  173,
      204,  713,  198,  200,  199,  174,  198,  200,  199,  201,
      237,  203,  197,  201,  202,  203,  712,  201,  202,  173,
      422,  201,  202,  295,  174,  634,  202,  174,  170,  170,
      170,  208,  170,  170,  170,  198,  419,  204,  173,  635,
      732,  173,  711,  710,  203,  295,  174,  271,  271,  271,
      201,  642,  733,  208,  198,  202,  204,  198,  744,  204,

      173,  295,  272,  203,  709,  174,  203,  636,  174,  209,
      638,  732,  209,  738,  202,  217,  198,  202,  204,  173,
      708,  637,  173,  733,  639,  203,  295,  174,  327,  327,
      327,  201,  295,  707,  217,  198,  202,  204,  198,  732,
      204,  173,  295,  328,  203,  295,  758,  203,  735,  663,
      201,  706,  705,  201,  753,  218,  730,  198,  218,  204,
      316,  316,  316,  316,  316,  316,  203,  329,  329,  329,
      295,  763,  201,  329,  329,  329,  318,  202,  295,  318,
      271,  271,  271,  331,  334,  334,  334,  759,  335,  331,
      295,  336,  341,  341,  341,  272,  341,  341,  341,  319,

      346,  346,  346,  348,  348,  348,  704,  760,  343,  348,
      348,  348,  343,  332,  697,  347,  359,  359,  359,  350,
      359,  359,  359,  295,  295,  350,  376,  376,  376,  316,
      316,  316,  361,  316,  316,  316,  361,  316,  316,  316,
      295,  377,  351,  344,  696,  318,  384,  384,  384,  318,
      387,  387,  387,  318,  327,  327,  327,  389,  389,  389,
      765,  390,  761,  762,  391,  329,  329,  329,  695,  328,
      381,  362,  329,  329,  329,  329,  329,  329,  334,  334,
      334,  331,  335,  764,  694,  336,  693,  692,  331,  691,
      295,  331,  395,  395,  395,  341,  341,  341,  341,  341,

      341,  341,  341,  341,  346,  346,  346,  396,  402,  402,
      402,  343,  403,  690,  343,  404,  392,  343,  295,  347,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  406,
      406,  406,  408,  408,  408,  400,  350,  771,  766,  350,
      689,  688,  350,  397,  407,  687,  295,  409,  412,  412,
      412,  415,  415,  415,  359,  359,  359,  359,  359,  359,
      426,  426,  426,  413,  686,  295,  416,  359,  359,  359,
      361,  685,  680,  361,  679,  678,  405,  421,  421,  421,
      428,  428,  428,  361,  431,  431,  431,  376,  376,  376,
      443,  443,  443,  422,  423,  429,  434,  434,  434,  432,

      435,  767,  377,  436,  417,  438,  438,  438,  316,  316,
      316,  384,  384,  384,  446,  446,  446,  439,  677,  771,
      440,  387,  387,  387,  318,  389,  389,  389,  676,  390,
      295,  295,  391,  329,  329,  329,  450,  450,  450,  395,
      395,  395,  458,  458,  458,  675,  674,  442,  295,  331,
      769,  451,  295,  673,  396,  452,  452,  452,  459,  453,
      672,  671,  454,  460,  460,  460,  402,  402,  402,  670,
      403,  669,  770,  404,  348,  348,  348,  448,  406,  406,
      406,  462,  462,  462,  768,  463,  668,  667,  464,  666,
      350,  662,  661,  407,  408,  408,  408,  465,  465,  465,

      660,  466,  659,  658,  467,  412,  412,  412,  657,  409,
      656,  461,  470,  470,  470,  655,  471,  654,  653,  472,
      413,  415,  415,  415,  474,  474,  474,  652,  475,  651,
      650,  476,  359,  359,  359,  649,  416,  421,  421,  421,
      426,  426,  426,  428,  428,  428,  648,  647,  361,  646,
      484,  484,  484,  422,  485,  627,  626,  486,  429,  625,
      431,  431,  431,  488,  488,  488,  624,  489,  620,  599,
      490,  438,  438,  438,  480,  432,  598,  434,  434,  434,
      597,  435,  596,  477,  436,  593,  440,  585,  494,  494,
      494,  481,  495,  581,  574,  496,  498,  498,  498,  443,

      443,  443,  500,  500,  500,  446,  446,  446,  502,  502,
      502,  573,  499,  329,  329,  329,  450,  450,  450,  505,
      505,  505,  572,  506,  571,  562,  507,  561,  560,  331,
      554,  451,  452,  452,  452,  553,  453,  549,  548,  454,
      458,  458,  458,  460,  460,  460,  348,  348,  348,  503,
      462,  462,  462,  547,  463,  546,  459,  464,  545,  465,
      465,  465,  350,  466,  544,  543,  467,  470,  470,  470,
      542,  471,  536,  531,  472,  474,  474,  474,  530,  475,
      527,  526,  476,  519,  519,  519,  484,  484,  484,  525,
      485,  521,  511,  486,  488,  488,  488,  518,  489,  520,

      517,  490,  528,  528,  528,  494,  494,  494,  516,  495,
      510,  509,  496,  498,  498,  498,  508,  529,  500,  500,
      500,  532,  532,  532,  502,  502,  502,  504,  501,  499,
      533,  533,  533,  535,  535,  535,  505,  505,  505,  497,
      506,  493,  492,  507,  491,  487,  534,  537,  537,  537,
      539,  539,  539,  348,  348,  348,  519,  519,  519,  555,
      555,  555,  538,  483,  482,  540,  528,  528,  528,  350,
      422,  478,  520,  473,  556,  557,  557,  557,  469,  558,
      468,  529,  559,  532,  532,  532,  533,  533,  533,  535,
      535,  535,  537,  537,  537,  457,  563,  563,  563,  456,

      564,  455,  534,  565,  449,  541,  447,  538,  539,  539,
      539,  566,  566,  566,  445,  567,  444,  441,  568,  569,
      569,  569,  437,  540,  575,  575,  575,  577,  577,  577,
      579,  579,  579,  433,  430,  570,  582,  582,  582,  576,
      427,  425,  578,  424,  418,  580,  586,  586,  586,  555,
      555,  555,  295,  588,  588,  588,  414,  589,  411,  410,
      590,  587,  401,  399,  556,  557,  557,  557,  398,  558,
      394,  393,  559,  591,  591,  591,  594,  594,  594,  563,
      563,  563,  388,  564,  386,  385,  565,  383,  592,  382,
      380,  595,  566,  566,  566,  379,  567,  378,  375,  568,

      569,  569,  569,  575,  575,  575,  600,  600,  600,  374,
      601,  373,  372,  602,  371,  370,  570,  369,  576,  577,
      577,  577,  603,  603,  603,  368,  604,  367,  366,  605,
      579,  579,  579,  365,  578,  606,  606,  606,  295,  607,
      363,  358,  608,  357,  356,  580,  582,  582,  582,  612,
      612,  612,  586,  586,  586,  355,  614,  614,  614,  354,
      615,  353,  295,  616,  613,  352,  345,  587,  588,  588,
      588,  340,  589,  339,  338,  590,  591,  591,  591,  609,
      617,  617,  617,  337,  618,  333,  326,  619,  594,  594,
      594,  592,  621,  621,  621,  325,  622,  324,  323,  623,

      600,  600,  600,  595,  601,  322,  321,  602,  603,  603,
      603,  320,  604,  315,  314,  605,  606,  606,  606,  313,
      607,  312,  311,  608,  612,  612,  612,  643,  643,  643,
      310,  644,  309,  308,  645,  307,  614,  614,  614,  613,
      615,  306,  305,  616,  617,  617,  617,  304,  618,  303,
      302,  619,  621,  621,  621,  301,  622,  298,  296,  623,
      643,  643,  643,  295,  644,  293,  292,  645,  683,  683,
      683,  698,  698,  698,  699,  699,  699,  683,  683,  683,
      291,  289,  288,  684,  422,  287,  286,  295,  285,  700,
      422,  284,  684,  422,  701,  701,  701,  283,  702,  282,

      280,  703,  698,  698,  698,  699,  699,  699,  279,  278,
      422,  276,  718,  718,  718,  275,  719,  274,  295,  720,
      700,  422,  701,  701,  701,  273,  702,  270,  422,  703,
      717,  269,  742,  742,  742,  754,  754,  754,  422,  420,
      420,  420,  420,  420,  420,  420,  420,  420,  422,  423,
      420,  295,  267,  420,  420,  420,  422,  420,  750,  750,
      750,  266,  751,  265,  264,  752,  742,  742,  742,  263,
      262,  420,  420,  420,  420,  420,  420,  420,  420,  420,
      420,  420,  422,  261,  420,  260,  259,  420,  420,  420,
      422,  420,  718,  718,  718,  257,  719,  256,  255,  720,

      750,  750,  750,  480,  751,  420,  420,  752,  422,  420,
      420,  420,  420,  420,  736,  420,  420,  420,  254,  253,
      420,  252,  251,  420,  420,  420,  422,  420,  250,  249,
      248,  247,  246,  245,  244,  239,  236,  746,  746,  746,
      238,  420,  420,  420,  420,  420,  420,  420,  420,  420,
      420,  736,  747,  234,  420,  233,  229,  420,  420,  420,
      422,  420,  746,  746,  746,  754,  754,  754,  228,  755,
      227,  226,  756,  225,  223,  420,  420,  747,  772,  772,
      772,  295,  772,  772,  772,  221,  219,  216,  215,  214,
      213,  212,  210,  207,  773,  205,  194,  193,  773,   68,

       68,   68,   68,   68,   68,   68,   69,   69,   69,   69,
       69,   69,   69,   74,   74,   74,   74,   74,   74,   74,
       77,   77,   77,   77,   77,   77,   77,   80,   80,   80,
       80,   80,   80,   80,   83,   83,   83,   83,   83,   83,
       83,   90,   90,   90,   90,   90,   90,   90,  108,  108,
      108,  108,  108,  108,  108,  118,  118,  118,  118,  118,
      118,  118,  122,  122,  122,  122,  122,  122,  122,  138,
      138,  138,  138,  138,  138,  138,  146,  146,  146,  146,
      146,  146,  146,  150,  150,  150,  150,  150,  150,  150,
      165,  165,  165,  165,  165,  165,  165,  187,  187,  187,

      192,  187,  206,  206,  206,  191,  206,  211,  211,  211,
      190,  211,  220,  220,  220,  186,  220,  224,  224,  224,
      184,  224,  235,  235,  235,  235,  235,  178,  235,  258,
      177,  258,  268,  178,  268,  277,  177,  277,  281,  176,
      281,  290,  175,  290,  294,  294,  294,  294,  294,  294,
      294,  300,  774,  774,  300,  317,  317,  317,  317,  317,
      317,  330,  330,  330,  330,  330,  330,  342,  342,  342,
      342,  342,  342,  349,  349,  349,  349,  349,  349,  360,
      360,  360,  360,  360,  360,  420,  420,  420,  420,  420,
      420,  420,  721,  721,  721,  721,  721,  721,  721,  722,

      722,  722,  722,  722,  722,  722,  731,  731,  731,  731,
      731,  731,  731,  734,  734,  734,  734,  734,  734,  734,
      739,  739,  739,  739,  739,  739,  739,  741,  741,  741,
      741,  741,  741,  741,   67,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774

    } ;

static const flex_int16_t yy_chk[2195] =
    {   0,
        0,    3,    3,    3,    4,    4,    4,    5,    5,    5,
        6,    6,    6,    9,  179,    3,   10,   11,    4,   12,
        9,    5,  481,   10,    6,    7,    7,    7,    8,    8,
        8,   13,   13,   11,  297,   12,   13,   13,  297,    7,
       14,   14,    8,  481,   13,   14,   14,   15,   15,  101,
       15,   72,   15,   14,   16,   16,  101,   16,  179,   16,
       15,   17,   17,   18,   18,   72,   73,   16,   19,   19,
       19,   20,   20,   20,   23,   23,   23,   24,   24,   24,
       73,  107,   19,  164,  240,   20,  240,  107,   23,  164,
      180,   24,   17,  180,   18,   21,   21,   21,   21,   21,

       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   25,   25,   25,   26,   26,   26,
       27,   27,   27,   28,   28,   28,  466,  467,   25,  480,
      745,   26,  466,  467,   27,  523,   76,   28,   29,   29,
       29,   30,   30,   30,   31,   31,   31,   32,   32,   32,
       76,  522,   29,  551,  523,   30,  584,  522,   31,  480,

       99,   32,   33,   33,   33,   34,   34,   34,   35,   35,
       35,   36,   36,   36,   99,  741,   33,  732,  732,   34,
      740,  584,   35,  739,  551,   36,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,  610,
       37,   37,   37,   37,   37,  583,   39,   39,   39,   40,
       40,   40,   41,   41,   41,   42,   42,   42,   37,   37,
       39,  641,  119,   40,  610,  583,   41,  737,  735,   42,
       70,   70,   70,   71,   71,   71,  119,   37,   38,   38,
       38,   38,   38,   38,   38,   38,   38,   38,   38,   38,
       38,  641,   38,   38,   38,   38,   38,  609,   43,   43,

       43,   44,   44,   44,   45,   45,   45,   46,   46,   46,
       38,   38,   43,  744,  131,   44,  733,  609,   45,  744,
      723,   46,   75,   75,   75,   96,   96,   96,  131,   38,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   49,
       49,   49,   50,   50,   50,   51,   51,   51,   52,   52,

       52,  524,  642,   49,  715,  663,   50,  713,  664,   51,
      711,  147,   52,   53,   53,   53,   54,   54,   54,   55,
       55,   55,   56,   56,   56,  147,  709,   53,  663,  707,
       54,  664,  642,   55,  705,  524,   56,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
      704,   57,   57,   57,   57,   57,  755,   59,   59,   59,
       60,   60,   60,   63,   63,   63,   64,   64,   64,   57,
       57,   59,   94,  157,   60,  237,  755,   63,  552,  697,
       64,   86,  109,  109,  109,  237,   94,  157,   57,   58,
       58,   58,   58,   58,   58,   58,   58,   58,   58,   58,

       58,   58,   94,   58,   58,   58,   58,   58,  479,   86,
      116,  116,  116,  552,  720,   86,  123,  123,  123,  479,
       86,   58,   58,  720,  419,   86,  128,  128,  128,  139,
      139,  139,  144,  144,  144,  151,  151,  151,  419,  696,
       58,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,

       65,   65,   66,   66,  110,   65,  601,   66,  112,  602,
      152,  110,  111,   65,  695,   66,  113,  152,  110,  111,
      601,  604,  112,  602,  152,  167,  111,  154,  154,  154,
      113,   65,  167,   66,  110,  604,  110,  171,  112,  167,
      112,  694,  111,  110,  111,  114,  113,  112,  113,  110,
      171,  111,  114,  112,  110,  113,  693,  111,  112,  114,
      611,  113,  111,  364,  124,  605,  113,  125,  166,  166,
      166,  124,  170,  170,  170,  114,  364,  114,  124,  605,
      719,  125,  692,  691,  114,  738,  126,  212,  212,  212,
      114,  611,  719,  126,  124,  114,  124,  125,  738,  125,

      126,  730,  212,  124,  690,  141,  125,  607,  140,  124,
      608,  731,  125,  730,  124,  140,  126,  125,  126,  141,
      689,  607,  140,  731,  608,  126,  756,  142,  267,  267,
      267,  126,  640,  688,  142,  141,  126,  141,  140,  734,
      140,  142,  717,  267,  141,  748,  756,  140,  734,  640,
      141,  687,  686,  140,  748,  141,  717,  142,  140,  142,
      258,  258,  258,  259,  259,  259,  142,  268,  268,  268,
      757,  761,  142,  269,  269,  269,  258,  142,  761,  259,
      271,  271,  271,  268,  272,  272,  272,  757,  272,  269,
      758,  272,  277,  277,  277,  271,  278,  278,  278,  259,

      280,  280,  280,  281,  281,  281,  685,  758,  277,  282,
      282,  282,  278,  269,  680,  280,  290,  290,  290,  281,
      291,  291,  291,  759,  760,  282,  312,  312,  312,  316,
      316,  316,  290,  317,  317,  317,  291,  319,  319,  319,
      763,  312,  282,  278,  679,  316,  322,  322,  322,  317,
      325,  325,  325,  319,  327,  327,  327,  328,  328,  328,
      763,  328,  759,  760,  328,  329,  329,  329,  678,  327,
      319,  291,  330,  330,  330,  332,  332,  332,  334,  334,
      334,  329,  334,  762,  677,  334,  676,  675,  330,  674,
      762,  332,  338,  338,  338,  341,  341,  341,  342,  342,

      342,  344,  344,  344,  346,  346,  346,  338,  347,  347,
      347,  341,  347,  673,  342,  347,  332,  344,  764,  346,
      348,  348,  348,  349,  349,  349,  351,  351,  351,  352,
      352,  352,  353,  353,  353,  344,  348,  770,  764,  349,
      672,  671,  351,  338,  352,  670,  770,  353,  356,  356,
      356,  358,  358,  358,  359,  359,  359,  360,  360,  360,
      370,  370,  370,  356,  669,  765,  358,  362,  362,  362,
      359,  666,  662,  360,  661,  660,  351,  365,  365,  365,
      372,  372,  372,  362,  374,  374,  374,  376,  376,  376,
      382,  382,  382,  365,  365,  372,  377,  377,  377,  374,

      377,  765,  376,  377,  362,  379,  379,  379,  381,  381,
      381,  384,  384,  384,  386,  386,  386,  379,  659,  769,
      379,  387,  387,  387,  381,  389,  389,  389,  658,  389,
      767,  769,  389,  392,  392,  392,  394,  394,  394,  395,
      395,  395,  400,  400,  400,  657,  656,  381,  766,  392,
      767,  394,  768,  655,  395,  396,  396,  396,  400,  396,
      654,  653,  396,  401,  401,  401,  402,  402,  402,  652,
      402,  651,  768,  402,  405,  405,  405,  392,  406,  406,
      406,  407,  407,  407,  766,  407,  650,  648,  407,  646,
      405,  639,  638,  406,  408,  408,  408,  409,  409,  409,

      637,  409,  636,  635,  409,  412,  412,  412,  634,  408,
      633,  405,  413,  413,  413,  632,  413,  631,  630,  413,
      412,  415,  415,  415,  416,  416,  416,  629,  416,  628,
      627,  416,  417,  417,  417,  626,  415,  421,  421,  421,
      426,  426,  426,  428,  428,  428,  625,  624,  417,  620,
      429,  429,  429,  421,  429,  599,  598,  429,  428,  597,
      431,  431,  431,  432,  432,  432,  596,  432,  593,  574,
      432,  438,  438,  438,  421,  431,  573,  434,  434,  434,
      572,  434,  571,  417,  434,  561,  438,  553,  440,  440,
      440,  421,  440,  549,  545,  440,  442,  442,  442,  443,

      443,  443,  444,  444,  444,  446,  446,  446,  447,  447,
      447,  544,  442,  448,  448,  448,  450,  450,  450,  451,
      451,  451,  543,  451,  542,  536,  451,  531,  530,  448,
      526,  450,  452,  452,  452,  525,  452,  521,  518,  452,
      458,  458,  458,  460,  460,  460,  461,  461,  461,  448,
      462,  462,  462,  517,  462,  516,  458,  462,  515,  465,
      465,  465,  461,  465,  514,  513,  465,  470,  470,  470,
      512,  470,  508,  497,  470,  474,  474,  474,  493,  474,
      491,  487,  474,  477,  477,  477,  484,  484,  484,  483,
      484,  478,  461,  484,  488,  488,  488,  473,  488,  477,

      469,  488,  492,  492,  492,  494,  494,  494,  468,  494,
      457,  456,  494,  498,  498,  498,  455,  492,  500,  500,
      500,  501,  501,  501,  502,  502,  502,  449,  445,  498,
      503,  503,  503,  504,  504,  504,  505,  505,  505,  441,
      505,  439,  437,  505,  433,  430,  503,  509,  509,  509,
      510,  510,  510,  511,  511,  511,  519,  519,  519,  527,
      527,  527,  509,  427,  423,  510,  528,  528,  528,  511,
      420,  418,  519,  414,  527,  529,  529,  529,  411,  529,
      410,  528,  529,  532,  532,  532,  533,  533,  533,  535,
      535,  535,  537,  537,  537,  399,  538,  538,  538,  398,

      538,  397,  533,  538,  393,  511,  388,  537,  539,  539,
      539,  540,  540,  540,  385,  540,  383,  380,  540,  541,
      541,  541,  378,  539,  546,  546,  546,  547,  547,  547,
      548,  548,  548,  375,  373,  541,  550,  550,  550,  546,
      371,  369,  547,  368,  363,  548,  554,  554,  554,  555,
      555,  555,  550,  556,  556,  556,  357,  556,  355,  354,
      556,  554,  345,  340,  555,  557,  557,  557,  339,  557,
      337,  333,  557,  560,  560,  560,  562,  562,  562,  563,
      563,  563,  326,  563,  324,  323,  563,  321,  560,  320,
      315,  562,  566,  566,  566,  314,  566,  313,  311,  566,

      569,  569,  569,  575,  575,  575,  576,  576,  576,  310,
      576,  309,  308,  576,  307,  306,  569,  305,  575,  577,
      577,  577,  578,  578,  578,  302,  578,  301,  300,  578,
      579,  579,  579,  298,  577,  580,  580,  580,  294,  580,
      292,  289,  580,  288,  287,  579,  582,  582,  582,  585,
      585,  585,  586,  586,  586,  286,  587,  587,  587,  285,
      587,  284,  582,  587,  585,  283,  279,  586,  588,  588,
      588,  276,  588,  275,  274,  588,  591,  591,  591,  582,
      592,  592,  592,  273,  592,  270,  266,  592,  594,  594,
      594,  591,  595,  595,  595,  265,  595,  264,  263,  595,

      600,  600,  600,  594,  600,  262,  261,  600,  603,  603,
      603,  260,  603,  257,  256,  603,  606,  606,  606,  255,
      606,  254,  253,  606,  612,  612,  612,  613,  613,  613,
      252,  613,  251,  250,  613,  249,  614,  614,  614,  612,
      614,  248,  246,  614,  617,  617,  617,  245,  617,  244,
      243,  617,  621,  621,  621,  242,  621,  238,  236,  621,
      643,  643,  643,  235,  643,  234,  233,  643,  665,  665,
      665,  681,  681,  681,  682,  682,  682,  683,  683,  683,
      232,  231,  230,  665,  665,  229,  228,  681,  227,  682,
      682,  226,  683,  683,  684,  684,  684,  225,  684,  222,

      221,  684,  698,  698,  698,  699,  699,  699,  218,  217,
      684,  216,  700,  700,  700,  215,  700,  214,  698,  700,
      699,  699,  701,  701,  701,  213,  701,  209,  700,  701,
      698,  208,  736,  736,  736,  753,  753,  753,  701,  702,
      702,  702,  702,  702,  702,  702,  702,  702,  736,  736,
      702,  753,  207,  702,  702,  702,  702,  702,  747,  747,
      747,  204,  747,  203,  202,  747,  742,  742,  742,  201,
      200,  702,  702,  703,  703,  703,  703,  703,  703,  703,
      703,  703,  742,  199,  703,  198,  197,  703,  703,  703,
      703,  703,  718,  718,  718,  196,  718,  195,  194,  718,

      750,  750,  750,  742,  750,  703,  703,  750,  718,  721,
      721,  721,  721,  721,  721,  721,  721,  721,  193,  192,
      721,  191,  190,  721,  721,  721,  721,  721,  189,  188,
      185,  184,  183,  182,  181,  175,  174,  743,  743,  743,
      172,  721,  721,  722,  722,  722,  722,  722,  722,  722,
      722,  722,  743,  169,  722,  168,  163,  722,  722,  722,
      722,  722,  746,  746,  746,  754,  754,  754,  162,  754,
      161,  160,  754,  159,  155,  722,  722,  746,  771,  771,
      771,  754,  772,  772,  772,  149,  145,  137,  136,  135,
      134,  133,  129,  121,  771,  117,  106,  105,  772,  775,

      775,  775,  775,  775,  775,  775,  776,  776,  776,  776,
      776,  776,  776,  777,  777,  777,  777,  777,  777,  777,
      778,  778,  778,  778,  778,  778,  778,  779,  779,  779,
      779,  779,  779,  779,  780,  780,  780,  780,  780,  780,
      780,  781,  781,  781,  781,  781,  781,  781,  782,  782,
      782,  782,  782,  782,  782,  783,  783,  783,  783,  783,
      783,  783,  784,  784,  784,  784,  784,  784,  784,  785,
      785,  785,  785,  785,  785,  785,  786,  786,  786,  786,
      786,  786,  786,  787,  787,  787,  787,  787,  787,  787,
      788,  788,  788,  788,  788,  788,  788,  789,  789,  789,

      104,  789,  790,  790,  790,  103,  790,  791,  791,  791,
      102,  791,  792,  792,  792,   97,  792,  793,  793,  793,
       93,  793,  794,  794,  794,  794,  794,   92,  794,  795,
       91,  795,  796,   85,  796,  797,   84,  797,  798,   82,
      798,  799,   79,  799,  800,  800,  800,  800,  800,  800,
      800,  801,   67,    0,  801,  802,  802,  802,  802,  802,
      802,  803,  803,  803,  803,  803,  803,  804,  804,  804,
      804,  804,  804,  805,  805,  805,  805,  805,  805,  806,
      806,  806,  806,  806,  806,  807,  807,  807,  807,  807,
      807,  807,  808,  808,  808,  808,  808,  808,  808,  809,

      809,  809,  809,  809,  809,  809,  810,  810,  810,  810,
      810,  810,  810,  811,  811,  811,  811,  811,  811,  811,
      812,  812,  812,  812,  812,  812,  812,  813,  813,  813,
      813,  813,  813,  813,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774

    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[141] =
    {   0,
0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 
    0, 0, 1, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 
    1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 1, 
    0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
/* Validating XML processor for src/simdag/dax.dtd.
 *
 * This program was generated with the FleXML XML processor generator.
 * FleXML is Copyright (C) 1999-2005 Kristoffer Rose.  All rights reserved.
 * FleXML is Copyright (C) 2003-2013 Martin Quinson.  All rights reserved.
 * (1.9.6).
 * 
 * There are two, intertwined parts to this program, part A and part B.
 *
 * Part A
 * ------
 * 
 * Some parts, here collectively called "Part A", are found in the 
 * FleXML package.  They are Copyright (C) 1999-2005 Kristoffer Rose
 * and Copyright (C) 2003-2013 Martin Quinson. All rights reserved.
 *
 * You can redistribute, use, perform, display and/or modify "Part A"
 * provided the following two conditions hold:
 *
 * 1. The program is distributed WITHOUT ANY WARRANTY from the author of
 *    FleXML; without even the implied warranty of MERCHANTABILITY or
 *    FITNESS FOR A PARTICULAR PURPOSE.
 *
 * 2. The program distribution conditions do not in any way affect the
 *    distribution conditions of the FleXML system used to generate this
 *    file or any version of FleXML derived from that system.
 *
 * Notice that these are explicit rights granted to you for files
 * generated by the FleXML system.  For your rights in connection with
 * the FleXML system itself please consult the GNU General Public License.
 * 
 * Part B
 * ------
 * 
 * The other parts, here collectively called "Part B", and which came 
 * from the DTD used by FleXML to generate this program, can be 
 * distributed (or not, as the case may be) under the terms of whoever
 * wrote them, provided these terms respect and obey the two conditions 
 * above under the heading "Part A".
 *
 * The author of and contributors to FleXML specifically disclaim
 * any copyright interest in "Part B", unless "Part B" was written 
 * by the author of or contributors to FleXML.
 * 
 */

/* Version strings. */
const char dax__flexml_version[] = "1.9.6";

/* ANSI headers. */
#include <stdlib.h> /* for realloc() -- needed here when using flex 2.5.4 */
#include <stdio.h>
#include <string.h>
#include <assert.h>
#include <stdarg.h>
#include <ctype.h>
     
#if defined(_WIN32) || defined(__WIN32__) || defined(WIN32) || defined(__TOS_WIN__)
# ifndef __STRICT_ANSI__
#  include <io.h>
#  include <process.h>
# endif
#else
# include <unistd.h>
#endif
     
#ifndef FLEXML_INDEXSTACKSIZE
#define FLEXML_INDEXSTACKSIZE 1000
#endif

/* Generated definitions. */
#define FLEXML_yylineno
#ifndef FLEXML_BUFFERSTACKSIZE
#define FLEXML_BUFFERSTACKSIZE 1000000
#endif
#define FLEXML_NEED_BUFFERLIT

/* XML processor api. */
/* FleXML-provided data. */
int dax__pcdata_ix;
extern char *dax__bufferstack;
#define dax__pcdata (dax__bufferstack + dax__pcdata_ix)
AT_dax__adag_childCount AX_dax__adag_childCount;
#define A_dax__adag_childCount (dax__bufferstack + AX_dax__adag_childCount)
short int dax__adag_childCount_isset;
AT_dax__adag_count AX_dax__adag_count;
#define A_dax__adag_count (dax__bufferstack + AX_dax__adag_count)
short int dax__adag_count_isset;
AT_dax__adag_fileCount AX_dax__adag_fileCount;
#define A_dax__adag_fileCount (dax__bufferstack + AX_dax__adag_fileCount)
short int dax__adag_fileCount_isset;
AT_dax__adag_index AX_dax__adag_index;
#define A_dax__adag_index (dax__bufferstack + AX_dax__adag_index)
short int dax__adag_index_isset;
AT_dax__adag_jobCount AX_dax__adag_jobCount;
#define A_dax__adag_jobCount (dax__bufferstack + AX_dax__adag_jobCount)
short int dax__adag_jobCount_isset;
AT_dax__adag_name AX_dax__adag_name;
#define A_dax__adag_name (dax__bufferstack + AX_dax__adag_name)
short int dax__adag_name_isset;
AT_dax__adag_version AX_dax__adag_version;
#define A_dax__adag_version (dax__bufferstack + AX_dax__adag_version)
short int dax__adag_version_isset;
AT_dax__adag_xmlns AX_dax__adag_xmlns;
#define A_dax__adag_xmlns (dax__bufferstack + AX_dax__adag_xmlns)
short int dax__adag_xmlns_isset;
AT_dax__adag_xmlns_c_xsi AX_dax__adag_xmlns_c_xsi;
#define A_dax__adag_xmlns_c_xsi (dax__bufferstack + AX_dax__adag_xmlns_c_xsi)
short int dax__adag_xmlns_c_xsi_isset;
AT_dax__adag_xsi_c_schemaLocation AX_dax__adag_xsi_c_schemaLocation;
#define A_dax__adag_xsi_c_schemaLocation (dax__bufferstack + AX_dax__adag_xsi_c_schemaLocation)
short int dax__adag_xsi_c_schemaLocation_isset;
AT_dax__child_ref AX_dax__child_ref;
#define A_dax__child_ref (dax__bufferstack + AX_dax__child_ref)
short int dax__child_ref_isset;
AT_dax__job_id AX_dax__job_id;
#define A_dax__job_id (dax__bufferstack + AX_dax__job_id)
short int dax__job_id_isset;
AT_dax__job_level AX_dax__job_level;
#define A_dax__job_level (dax__bufferstack + AX_dax__job_level)
short int dax__job_level_isset;
AT_dax__job_name AX_dax__job_name;
#define A_dax__job_name (dax__bufferstack + AX_dax__job_name)
short int dax__job_name_isset;
AT_dax__job_namespace AX_dax__job_namespace;
#define A_dax__job_namespace (dax__bufferstack + AX_dax__job_namespace)
short int dax__job_namespace_isset;
AT_dax__job_runtime AX_dax__job_runtime;
#define A_dax__job_runtime (dax__bufferstack + AX_dax__job_runtime)
short int dax__job_runtime_isset;
AT_dax__job_version AX_dax__job_version;
#define A_dax__job_version (dax__bufferstack + AX_dax__job_version)
short int dax__job_version_isset;
AT_dax__parent_ref AX_dax__parent_ref;
#define A_dax__parent_ref (dax__bufferstack + AX_dax__parent_ref)
short int dax__parent_ref_isset;
AT_dax__uses_file AX_dax__uses_file;
#define A_dax__uses_file (dax__bufferstack + AX_dax__uses_file)
short int dax__uses_file_isset;
AT_dax__uses_link AX_dax__uses_link;
#define A_dax__uses_link AX_dax__uses_link
short int dax__uses_link_isset;
AT_dax__uses_optional AX_dax__uses_optional;
#define A_dax__uses_optional AX_dax__uses_optional
short int dax__uses_optional_isset;
AT_dax__uses_register AX_dax__uses_register;
#define A_dax__uses_register AX_dax__uses_register
short int dax__uses_register_isset;
AT_dax__uses_size AX_dax__uses_size;
#define A_dax__uses_size (dax__bufferstack + AX_dax__uses_size)
short int dax__uses_size_isset;
AT_dax__uses_transfer AX_dax__uses_transfer;
#define A_dax__uses_transfer AX_dax__uses_transfer
short int dax__uses_transfer_isset;
AT_dax__uses_type AX_dax__uses_type;
#define A_dax__uses_type (dax__bufferstack + AX_dax__uses_type)
short int dax__uses_type_isset;

/* XML state. */
#ifdef FLEX_DEBUG
# define ENTER(state)	debug_enter(state,#state)
# define LEAVE		debug_leave()
# define SET(state)	debug_set(state,#state)
  static void debug_enter(int, const char*);
  static void debug_leave(void);
  static void debug_set(int, const char*);
#else
# define ENTER(state)	(yy_push_state(state))
# define LEAVE		(yy_pop_state())
# define SET(state)	BEGIN(state)
#endif

/* Generic actions. */
#define SKIP	/*skip*/
#define SUCCEED        CLEANUP; return 0

#define FAIL	return fail
static int fail(const char*, ...);

enum {flexml_max_err_msg_size = 512};
static char flexml_err_msg[flexml_max_err_msg_size];
const char * dax__parse_err_msg()
{
    return flexml_err_msg;
}
static void reset_dax__parse_err_msg()
{
    flexml_err_msg[0] = '\0';
}

/* Cleanup */
static void cleanup(void);
#define CLEANUP  cleanup()

/* Text buffer stack handling. */
char *dax__bufferstack = NULL;
static int blimit = FLEXML_BUFFERSTACKSIZE;
static int bnext = 1;

static int *indexstack = NULL;
static int ilimit = FLEXML_INDEXSTACKSIZE;
static int inext = 1;

#define BUFFERSET(P)  (P = bnext)
#define BUFFERPUTC(C) (ck_blimit(), dax__bufferstack[bnext++] = (C))
#define BUFFERDONE    (BUFFERPUTC('\0'))

#define BUFFERLITERAL(C, P) dax__bufferliteral(C, &(P), yytext)

/* after this is called, there are at least 2 slots left in the stack */
static int ck_blimit()
{
     if (bnext >= blimit) {
	 blimit += FLEXML_BUFFERSTACKSIZE + 2;
	 {
	     char *temp = (char *) realloc(dax__bufferstack, blimit);
	     assert(temp);
	     dax__bufferstack = temp;
	 }
     }
     return 0;
}

/* after this is called, there are at least 2 slots left in the stack */
static int ck_ilimit()
{
     if (inext >= ilimit) {
	 ilimit += FLEXML_INDEXSTACKSIZE + 2;
	 {
	     int *temp = (int *) realloc(indexstack, ilimit);
	     assert(temp);
	     indexstack = temp;
	 }
     }
     return 0;
}

#ifdef FLEXML_NEED_BUFFERLIT
static void dax__bufferliteral(char c, int* pp, const char* text)
{
   BUFFERSET(*pp);
   if (c) {
      const char *s = strchr(text, c), *e = strrchr(text, c);
      assert(s && e && s <= e);
      ++s;
      while (s < e) {
	 if (isspace(*s)) {
	    BUFFERPUTC(' ');
	    do ++s; while (s < e && isspace(*s));
	 } else
	   BUFFERPUTC(*s++);
      }
   } else {
      const char *s = text;
      while (*s)
	BUFFERPUTC(*s++);
   }
   BUFFERDONE;
}
#endif

static void pushbuffer(int p)
{
    ck_ilimit();
    indexstack[inext++] = p;
    indexstack[inext++] = bnext;    
}

static int popbuffer(void)
{
    assert(inext >= 2);
    bnext = indexstack[--inext];
    return indexstack[--inext];
}

/* General internal entities are `unput' back onto the input stream... */
#define ENTITYTEXT(T) \
  { char *s = (T), *e = s+strlen(s);\
    while (--e >= s) { unput(*e); }}

/* Flex standard options. */
#define YY_NO_INPUT 1
/* Flex user-requested options. */
/* XML character classes (currently restricted to ASCII). */
/* "Common syntactic structures." */
/* "Names and Tokens." */
/* Miscellaneous. */
/* Parser states (flex `exclusive start conditions'):
 *
 * PROLOG	the XML prolog of the document before <?xml...>
 * DOCTYPE	the XML prolog of the document after <?xml...>
 * EPILOG	after the root element
 * INCOMMENT	inside an XML comment <!--....-->
 * INPI		inside an XML PI <?...?>
 * VALUE1	inside a '...'-delimited literal
 * VALUE2	inside a "..."-delimited literal
 * CDATA	inside a <![CDATA[...] ]> section.
 * ROOT_<tag>	expect root element <tag>
 * AL_<tag>	inside the attribute list for <tag>
 * IN_<tag>	inside a <tag> with element contents (ready for end tag)
 * IMPOSSIBLE	dummy to permit disabling rules; must be last
 */

/* State names. */
const char* *dax__statenames=NULL;

#define INITIAL 0
#define PROLOG 1
#define DOCTYPE 2
#define EPILOG 3
#define INCOMMENT 4
#define INPI 5
#define VALUE1 6
#define VALUE2 7
#define CDATA 8
#define ROOT_dax__adag 9
#define AL_dax__adag 10
#define S_dax__adag 11
#define S_dax__adag_1 12
#define S_dax__adag_2 13
#define S_dax__adag_3 14
#define S_dax__adag_4 15
#define S_dax__adag_5 16
#define E_dax__adag 17
#define AL_dax__child 18
#define S_dax__child 19
#define S_dax__child_1 20
#define S_dax__child_2 21
#define E_dax__child 22
#define AL_dax__job 23
#define S_dax__job 24
#define S_dax__job_1 25
#define S_dax__job_2 26
#define E_dax__job 27
#define AL_dax__parent 28
#define E_dax__parent 29
#define AL_dax__uses 30
#define E_dax__uses 31
#define IMPOSSIBLE 32

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#if defined(_WIN32)
#  ifndef __STRICT_ANSI__
#    include <io.h>
#    include <process.h>
#  endif
#else
#  include <unistd.h>
#endif
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state ( int _new_state );
    
    static void yy_pop_state ( void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{

 /* Bypass Flex's default INITIAL state and begin by parsing the XML prolog. */
 SET(PROLOG);
 reset_dax__parse_err_msg();
 dax__bufferstack = (char *) malloc(FLEXML_BUFFERSTACKSIZE);
 assert(dax__bufferstack);
 #ifdef FLEX_DEBUG
 {
     int i;
     for (i = 0; i < blimit; i++) {
         dax__bufferstack[i] = '\377';
     }
 }
 #endif
 dax__bufferstack[0] = '\0';
 indexstack = (int *) malloc(FLEXML_INDEXSTACKSIZE * sizeof(int));
 assert(indexstack);
 indexstack[0] = 0;

  /* FleXML_init */
  bnext = inext = 1;
  dax__bufferliteral('\0', &bnext, "http://pegasus.isi.edu/schema/DAX");
  dax__bufferliteral('\0', &bnext, "http://www.w3.org/2001/XMLSchema-instance");
  dax__bufferliteral('\0', &bnext, "http://pegasus.isi.edu/schema/DAX http://pegasus.isi.edu/schema/dax-2.1.xsd");
  dax__bufferliteral('\0', &bnext, "1.0");
  dax__bufferliteral('\0', &bnext, "0.0");
  dax__bufferliteral('\0', &bnext, "data");
  if(!dax__statenames) {dax__statenames= (const char **)calloc(IMPOSSIBLE,sizeof(char*));
  dax__statenames[PROLOG] = NULL;
  dax__statenames[DOCTYPE] = NULL;
  dax__statenames[EPILOG] = NULL;
  dax__statenames[INCOMMENT] = NULL;
  dax__statenames[INPI] = NULL;
  dax__statenames[VALUE1] = NULL;
  dax__statenames[VALUE2] = NULL;
  dax__statenames[CDATA] = NULL;
  dax__statenames[ROOT_dax__adag] = NULL;
  dax__statenames[AL_dax__adag] = NULL;
  dax__statenames[S_dax__adag] = "adag";
  dax__statenames[S_dax__adag_1] = "adag";
  dax__statenames[S_dax__adag_2] = "adag";
  dax__statenames[S_dax__adag_3] = "adag";
  dax__statenames[S_dax__adag_4] = "adag";
  dax__statenames[S_dax__adag_5] = "adag";
  dax__statenames[E_dax__adag] = "adag";
  dax__statenames[AL_dax__child] = NULL;
  dax__statenames[S_dax__child] = "child";
  dax__statenames[S_dax__child_1] = "child";
  dax__statenames[S_dax__child_2] = "child";
  dax__statenames[E_dax__child] = "child";
  dax__statenames[AL_dax__job] = NULL;
  dax__statenames[S_dax__job] = "job";
  dax__statenames[S_dax__job_1] = "job";
  dax__statenames[S_dax__job_2] = "job";
  dax__statenames[E_dax__job] = "job";
  dax__statenames[AL_dax__parent] = NULL;
  dax__statenames[E_dax__parent] = "parent";
  dax__statenames[AL_dax__uses] = NULL;
  dax__statenames[E_dax__uses] = "uses";
  }

 /* COMMENTS and PIs: handled uniformly for efficiency. */

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 775 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2135 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
ENTER(INCOMMENT);
	YY_BREAK
case 2:
YY_RULE_SETUP
ENTER(INPI);
	YY_BREAK

case 3:
YY_RULE_SETUP
LEAVE;
	YY_BREAK
case 4:
case 5:
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
SKIP;
	YY_BREAK
case YY_STATE_EOF(INCOMMENT):
FAIL("EOF in comment.");
	YY_BREAK

case 7:
YY_RULE_SETUP
LEAVE;
	YY_BREAK
case 8:
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
SKIP;
	YY_BREAK
case YY_STATE_EOF(INPI):
FAIL("EOF in PI (processing instruction).");
	YY_BREAK

/* SPACES: skipped uniformly */
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
SKIP;
	YY_BREAK
/* PROLOG: determine root element and process it. */

case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
SET(ROOT_dax__adag); 
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
FAIL("Bad declaration %s.",yytext);
	YY_BREAK

case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
SET(ROOT_dax__adag);
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
FAIL("Bad declaration %s.",yytext);
	YY_BREAK
case 15:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in prolog.", yytext[0]);
	YY_BREAK
case YY_STATE_EOF(PROLOG):
case YY_STATE_EOF(DOCTYPE):
FAIL("EOF in prolog.");
	YY_BREAK

/* RULES DERIVED FROM DTD. */
/* <!-- Small DTD for DAX files. -->  */
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <adag> is not allowed here.");
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
{
  AX_dax__adag_childCount = 0;
  dax__adag_childCount_isset = 0;
  AX_dax__adag_count = 0;
  dax__adag_count_isset = 0;
  AX_dax__adag_fileCount = 0;
  dax__adag_fileCount_isset = 0;
  AX_dax__adag_index = 0;
  dax__adag_index_isset = 0;
  AX_dax__adag_jobCount = 0;
  dax__adag_jobCount_isset = 0;
  AX_dax__adag_name = 0;
  dax__adag_name_isset = 0;
  AX_dax__adag_version = 153;
  dax__adag_version_isset = 0;
  AX_dax__adag_xmlns = 1;
  dax__adag_xmlns_isset = 0;
  AX_dax__adag_xmlns_c_xsi = 35;
  dax__adag_xmlns_c_xsi_isset = 0;
  AX_dax__adag_xsi_c_schemaLocation = 77;
  dax__adag_xsi_c_schemaLocation_isset = 0;
  ENTER(AL_dax__adag); pushbuffer(0);
  }
	YY_BREAK

case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
if (dax__adag_childCount_isset != 0) {FAIL("Multiple definition of attribute childCount in <dax__adag>");} dax__adag_childCount_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_childCount);
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
if (dax__adag_childCount_isset != 0) {FAIL("Multiple definition of attribute childCount in <dax__adag>");}  dax__adag_childCount_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_childCount);
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
if (dax__adag_count_isset != 0) {FAIL("Multiple definition of attribute count in <dax__adag>");} dax__adag_count_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_count);
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
if (dax__adag_count_isset != 0) {FAIL("Multiple definition of attribute count in <dax__adag>");}  dax__adag_count_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_count);
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
if (dax__adag_fileCount_isset != 0) {FAIL("Multiple definition of attribute fileCount in <dax__adag>");} dax__adag_fileCount_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_fileCount);
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
if (dax__adag_fileCount_isset != 0) {FAIL("Multiple definition of attribute fileCount in <dax__adag>");}  dax__adag_fileCount_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_fileCount);
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
if (dax__adag_index_isset != 0) {FAIL("Multiple definition of attribute index in <dax__adag>");} dax__adag_index_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_index);
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
if (dax__adag_index_isset != 0) {FAIL("Multiple definition of attribute index in <dax__adag>");}  dax__adag_index_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_index);
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
if (dax__adag_jobCount_isset != 0) {FAIL("Multiple definition of attribute jobCount in <dax__adag>");} dax__adag_jobCount_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_jobCount);
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
if (dax__adag_jobCount_isset != 0) {FAIL("Multiple definition of attribute jobCount in <dax__adag>");}  dax__adag_jobCount_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_jobCount);
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
if (dax__adag_name_isset != 0) {FAIL("Multiple definition of attribute name in <dax__adag>");} dax__adag_name_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_name);
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
if (dax__adag_name_isset != 0) {FAIL("Multiple definition of attribute name in <dax__adag>");}  dax__adag_name_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_name);
	YY_BREAK
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
if (dax__adag_version_isset != 0) {FAIL("Multiple definition of attribute version in <dax__adag>");} dax__adag_version_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_version);
	YY_BREAK
case 31:
/* rule 31 can match eol */
YY_RULE_SETUP
if (dax__adag_version_isset != 0) {FAIL("Multiple definition of attribute version in <dax__adag>");}  dax__adag_version_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_version);
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
if (dax__adag_xmlns_isset != 0) {FAIL("Multiple definition of attribute xmlns in <dax__adag>");} dax__adag_xmlns_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_xmlns);
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
if (dax__adag_xmlns_isset != 0) {FAIL("Multiple definition of attribute xmlns in <dax__adag>");}  dax__adag_xmlns_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_xmlns);
	YY_BREAK
case 34:
/* rule 34 can match eol */
YY_RULE_SETUP
if (dax__adag_xmlns_c_xsi_isset != 0) {FAIL("Multiple definition of attribute xmlns:xsi in <dax__adag>");} dax__adag_xmlns_c_xsi_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_xmlns_c_xsi);
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
if (dax__adag_xmlns_c_xsi_isset != 0) {FAIL("Multiple definition of attribute xmlns:xsi in <dax__adag>");}  dax__adag_xmlns_c_xsi_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_xmlns_c_xsi);
	YY_BREAK
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
if (dax__adag_xsi_c_schemaLocation_isset != 0) {FAIL("Multiple definition of attribute xsi:schemaLocation in <dax__adag>");} dax__adag_xsi_c_schemaLocation_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__adag_xsi_c_schemaLocation);
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
if (dax__adag_xsi_c_schemaLocation_isset != 0) {FAIL("Multiple definition of attribute xsi:schemaLocation in <dax__adag>");}  dax__adag_xsi_c_schemaLocation_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__adag_xsi_c_schemaLocation);
	YY_BREAK
case 38:
YY_RULE_SETUP
{
  LEAVE; STag_dax__adag();dax__pcdata_ix = 0; ENTER(S_dax__adag);
 }
	YY_BREAK
case 39:
YY_RULE_SETUP
{
  LEAVE; STag_dax__adag(); dax__pcdata_ix = 0; ETag_dax__adag(); popbuffer(); /* attribute */
  switch (YY_START) {
   case ROOT_dax__adag: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 40:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of adag element.", yytext[0]);
	YY_BREAK
case 41:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `adag' element start tag.",yytext);
	YY_BREAK
case YY_STATE_EOF(AL_dax__adag):
FAIL("EOF in attribute list of `adag' element.");
	YY_BREAK

case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__adag();
  popbuffer(); /* attribute */
  switch (YY_START) {
   case ROOT_dax__adag: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 43:
/* rule 43 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</adag>' expected.",yytext);
	YY_BREAK
case 44:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</adag>' expected.",yytext[0]);
	YY_BREAK
case YY_STATE_EOF(E_dax__adag):
case YY_STATE_EOF(S_dax__adag):
case YY_STATE_EOF(S_dax__adag_1):
case YY_STATE_EOF(S_dax__adag_3):
case YY_STATE_EOF(S_dax__adag_5):
FAIL("Premature EOF: `</adag>' expected.");
	YY_BREAK

case 45:
/* rule 45 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <child> is not allowed here.");
	YY_BREAK
case 46:
/* rule 46 can match eol */
YY_RULE_SETUP
{
  AX_dax__child_ref = 0;
  dax__child_ref_isset = 0;
  ENTER(AL_dax__child); pushbuffer(0);
  }
	YY_BREAK

case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
if (dax__child_ref_isset != 0) {FAIL("Multiple definition of attribute ref in <dax__child>");} dax__child_ref_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__child_ref);
	YY_BREAK
case 48:
/* rule 48 can match eol */
YY_RULE_SETUP
if (dax__child_ref_isset != 0) {FAIL("Multiple definition of attribute ref in <dax__child>");}  dax__child_ref_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__child_ref);
	YY_BREAK
case 49:
YY_RULE_SETUP
{
  if (!AX_dax__child_ref) FAIL("Required attribute `ref' not set for `child' element.");
  LEAVE; STag_dax__child();dax__pcdata_ix = 0; ENTER(S_dax__child);
 }
	YY_BREAK
case 50:
YY_RULE_SETUP
{
  if (!AX_dax__child_ref) FAIL("Required attribute `ref' not set for `child' element.");
  LEAVE; STag_dax__child(); dax__pcdata_ix = 0; ETag_dax__child(); popbuffer(); /* attribute */
  switch (YY_START) {
   case S_dax__adag: case S_dax__adag_1: case S_dax__adag_3: case S_dax__adag_4: case S_dax__adag_5: SET(S_dax__adag_5); break;
  }
 }
	YY_BREAK
case 51:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of child element.", yytext[0]);
	YY_BREAK
case 52:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `child' element start tag.",yytext);
	YY_BREAK
case YY_STATE_EOF(AL_dax__child):
FAIL("EOF in attribute list of `child' element.");
	YY_BREAK

case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__child();
  popbuffer(); /* attribute */
  switch (YY_START) {
   case S_dax__adag: case S_dax__adag_1: case S_dax__adag_3: case S_dax__adag_4: case S_dax__adag_5: SET(S_dax__adag_5); break;
  }
 }
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</child>' expected.",yytext);
	YY_BREAK
case 55:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</child>' expected.",yytext[0]);
	YY_BREAK
case YY_STATE_EOF(E_dax__child):
case YY_STATE_EOF(S_dax__child):
case YY_STATE_EOF(S_dax__child_2):
FAIL("Premature EOF: `</child>' expected.");
	YY_BREAK

case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <job> is not allowed here.");
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
{
  AX_dax__job_id = 0;
  dax__job_id_isset = 0;
  AX_dax__job_level = 0;
  dax__job_level_isset = 0;
  AX_dax__job_name = 0;
  dax__job_name_isset = 0;
  AX_dax__job_namespace = 0;
  dax__job_namespace_isset = 0;
  AX_dax__job_runtime = 0;
  dax__job_runtime_isset = 0;
  AX_dax__job_version = 157;
  dax__job_version_isset = 0;
  ENTER(AL_dax__job); pushbuffer(0);
  }
	YY_BREAK

case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
if (dax__job_id_isset != 0) {FAIL("Multiple definition of attribute id in <dax__job>");} dax__job_id_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__job_id);
	YY_BREAK
case 59:
/* rule 59 can match eol */
YY_RULE_SETUP
if (dax__job_id_isset != 0) {FAIL("Multiple definition of attribute id in <dax__job>");}  dax__job_id_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__job_id);
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
if (dax__job_level_isset != 0) {FAIL("Multiple definition of attribute level in <dax__job>");} dax__job_level_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__job_level);
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
if (dax__job_level_isset != 0) {FAIL("Multiple definition of attribute level in <dax__job>");}  dax__job_level_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__job_level);
	YY_BREAK
case 62:
/* rule 62 can match eol */
YY_RULE_SETUP
if (dax__job_name_isset != 0) {FAIL("Multiple definition of attribute name in <dax__job>");} dax__job_name_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__job_name);
	YY_BREAK
case 63:
/* rule 63 can match eol */
YY_RULE_SETUP
if (dax__job_name_isset != 0) {FAIL("Multiple definition of attribute name in <dax__job>");}  dax__job_name_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__job_name);
	YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
if (dax__job_namespace_isset != 0) {FAIL("Multiple definition of attribute namespace in <dax__job>");} dax__job_namespace_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__job_namespace);
	YY_BREAK
case 65:
/* rule 65 can match eol */
YY_RULE_SETUP
if (dax__job_namespace_isset != 0) {FAIL("Multiple definition of attribute namespace in <dax__job>");}  dax__job_namespace_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__job_namespace);
	YY_BREAK
case 66:
/* rule 66 can match eol */
YY_RULE_SETUP
if (dax__job_runtime_isset != 0) {FAIL("Multiple definition of attribute runtime in <dax__job>");} dax__job_runtime_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__job_runtime);
	YY_BREAK
case 67:
/* rule 67 can match eol */
YY_RULE_SETUP
if (dax__job_runtime_isset != 0) {FAIL("Multiple definition of attribute runtime in <dax__job>");}  dax__job_runtime_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__job_runtime);
	YY_BREAK
case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
if (dax__job_version_isset != 0) {FAIL("Multiple definition of attribute version in <dax__job>");} dax__job_version_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__job_version);
	YY_BREAK
case 69:
/* rule 69 can match eol */
YY_RULE_SETUP
if (dax__job_version_isset != 0) {FAIL("Multiple definition of attribute version in <dax__job>");}  dax__job_version_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__job_version);
	YY_BREAK
case 70:
YY_RULE_SETUP
{
  if (!AX_dax__job_id) FAIL("Required attribute `id' not set for `job' element.");
  if (!AX_dax__job_name) FAIL("Required attribute `name' not set for `job' element.");
  if (!AX_dax__job_runtime) FAIL("Required attribute `runtime' not set for `job' element.");
  LEAVE; STag_dax__job();dax__pcdata_ix = 0; ENTER(S_dax__job);
 }
	YY_BREAK
case 71:
YY_RULE_SETUP
{
  if (!AX_dax__job_id) FAIL("Required attribute `id' not set for `job' element.");
  if (!AX_dax__job_name) FAIL("Required attribute `name' not set for `job' element.");
  if (!AX_dax__job_runtime) FAIL("Required attribute `runtime' not set for `job' element.");
  LEAVE; STag_dax__job(); dax__pcdata_ix = 0; ETag_dax__job(); popbuffer(); /* attribute */
  switch (YY_START) {
   case S_dax__adag: case S_dax__adag_2: case S_dax__adag_3: SET(S_dax__adag_3); break;
  }
 }
	YY_BREAK
case 72:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of job element.", yytext[0]);
	YY_BREAK
case 73:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `job' element start tag.",yytext);
	YY_BREAK
case YY_STATE_EOF(AL_dax__job):
FAIL("EOF in attribute list of `job' element.");
	YY_BREAK

case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__job();
  popbuffer(); /* attribute */
  switch (YY_START) {
   case S_dax__adag: case S_dax__adag_2: case S_dax__adag_3: SET(S_dax__adag_3); break;
  }
 }
	YY_BREAK
case 75:
/* rule 75 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</job>' expected.",yytext);
	YY_BREAK
case 76:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</job>' expected.",yytext[0]);
	YY_BREAK
case YY_STATE_EOF(E_dax__job):
case YY_STATE_EOF(S_dax__job):
case YY_STATE_EOF(S_dax__job_2):
FAIL("Premature EOF: `</job>' expected.");
	YY_BREAK

case 77:
/* rule 77 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <parent> is not allowed here.");
	YY_BREAK
case 78:
/* rule 78 can match eol */
YY_RULE_SETUP
{
  AX_dax__parent_ref = 0;
  dax__parent_ref_isset = 0;
  ENTER(AL_dax__parent); pushbuffer(0);
  }
	YY_BREAK

case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
if (dax__parent_ref_isset != 0) {FAIL("Multiple definition of attribute ref in <dax__parent>");} dax__parent_ref_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__parent_ref);
	YY_BREAK
case 80:
/* rule 80 can match eol */
YY_RULE_SETUP
if (dax__parent_ref_isset != 0) {FAIL("Multiple definition of attribute ref in <dax__parent>");}  dax__parent_ref_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__parent_ref);
	YY_BREAK
case 81:
YY_RULE_SETUP
{
  if (!AX_dax__parent_ref) FAIL("Required attribute `ref' not set for `parent' element.");
  LEAVE; STag_dax__parent();dax__pcdata_ix = 0; ENTER(E_dax__parent);
 }
	YY_BREAK
case 82:
YY_RULE_SETUP
{
  if (!AX_dax__parent_ref) FAIL("Required attribute `ref' not set for `parent' element.");
  LEAVE; STag_dax__parent(); dax__pcdata_ix = 0; ETag_dax__parent(); popbuffer(); /* attribute */
  switch (YY_START) {
   case S_dax__child: case S_dax__child_1: case S_dax__child_2: SET(S_dax__child_2); break;
  }
 }
	YY_BREAK
case 83:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of parent element.", yytext[0]);
	YY_BREAK
case 84:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `parent' element start tag.",yytext);
	YY_BREAK
case YY_STATE_EOF(AL_dax__parent):
FAIL("EOF in attribute list of `parent' element.");
	YY_BREAK

case 85:
/* rule 85 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__parent();
  popbuffer(); /* attribute */
  switch (YY_START) {
   case S_dax__child: case S_dax__child_1: case S_dax__child_2: SET(S_dax__child_2); break;
  }
 }
	YY_BREAK
case 86:
/* rule 86 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</parent>' expected.",yytext);
	YY_BREAK
case 87:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</parent>' expected.",yytext[0]);
	YY_BREAK
case YY_STATE_EOF(E_dax__parent):
FAIL("Premature EOF: `</parent>' expected.");
	YY_BREAK

/* <!-- ignored -->
  * <!-- ignored -->  */
case 88:
/* rule 88 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <uses> is not allowed here.");
	YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
{
  AX_dax__uses_file = 0;
  dax__uses_file_isset = 0;
  AX_dax__uses_link = AU_dax__uses_link;
  dax__uses_link_isset = 0;
  AX_dax__uses_optional = A_dax__uses_optional_false;
  dax__uses_optional_isset = 0;
  AX_dax__uses_register = A_dax__uses_register_true;
  dax__uses_register_isset = 0;
  AX_dax__uses_size = 0;
  dax__uses_size_isset = 0;
  AX_dax__uses_transfer = A_dax__uses_transfer_true;
  dax__uses_transfer_isset = 0;
  AX_dax__uses_type = 161;
  dax__uses_type_isset = 0;
  ENTER(AL_dax__uses); pushbuffer(0);
  }
	YY_BREAK

case 90:
/* rule 90 can match eol */
YY_RULE_SETUP
if (dax__uses_file_isset != 0) {FAIL("Multiple definition of attribute file in <dax__uses>");} dax__uses_file_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__uses_file);
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
if (dax__uses_file_isset != 0) {FAIL("Multiple definition of attribute file in <dax__uses>");}  dax__uses_file_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__uses_file);
	YY_BREAK
case 92:
/* rule 92 can match eol */
case 93:
/* rule 93 can match eol */
YY_RULE_SETUP
A_dax__uses_link = A_dax__uses_link_input;
	YY_BREAK
case 94:
/* rule 94 can match eol */
case 95:
/* rule 95 can match eol */
YY_RULE_SETUP
A_dax__uses_link = A_dax__uses_link_output;
	YY_BREAK
case 96:
/* rule 96 can match eol */
case 97:
/* rule 97 can match eol */
YY_RULE_SETUP
A_dax__uses_optional = A_dax__uses_optional_false;
	YY_BREAK
case 98:
/* rule 98 can match eol */
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
A_dax__uses_optional = A_dax__uses_optional_true;
	YY_BREAK
case 100:
/* rule 100 can match eol */
case 101:
/* rule 101 can match eol */
YY_RULE_SETUP
A_dax__uses_register = A_dax__uses_register_false;
	YY_BREAK
case 102:
/* rule 102 can match eol */
case 103:
/* rule 103 can match eol */
YY_RULE_SETUP
A_dax__uses_register = A_dax__uses_register_true;
	YY_BREAK
case 104:
/* rule 104 can match eol */
YY_RULE_SETUP
if (dax__uses_size_isset != 0) {FAIL("Multiple definition of attribute size in <dax__uses>");} dax__uses_size_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__uses_size);
	YY_BREAK
case 105:
/* rule 105 can match eol */
YY_RULE_SETUP
if (dax__uses_size_isset != 0) {FAIL("Multiple definition of attribute size in <dax__uses>");}  dax__uses_size_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__uses_size);
	YY_BREAK
case 106:
/* rule 106 can match eol */
case 107:
/* rule 107 can match eol */
YY_RULE_SETUP
A_dax__uses_transfer = A_dax__uses_transfer_false;
	YY_BREAK
case 108:
/* rule 108 can match eol */
case 109:
/* rule 109 can match eol */
YY_RULE_SETUP
A_dax__uses_transfer = A_dax__uses_transfer_true;
	YY_BREAK
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
if (dax__uses_type_isset != 0) {FAIL("Multiple definition of attribute type in <dax__uses>");} dax__uses_type_isset = 1; ENTER(VALUE1); BUFFERSET(AX_dax__uses_type);
	YY_BREAK
case 111:
/* rule 111 can match eol */
YY_RULE_SETUP
if (dax__uses_type_isset != 0) {FAIL("Multiple definition of attribute type in <dax__uses>");}  dax__uses_type_isset = 1; ENTER(VALUE2); BUFFERSET(AX_dax__uses_type);
	YY_BREAK
case 112:
YY_RULE_SETUP
{
  if (!AX_dax__uses_file) FAIL("Required attribute `file' not set for `uses' element.");
  if (!AX_dax__uses_size) FAIL("Required attribute `size' not set for `uses' element.");
  LEAVE; STag_dax__uses();dax__pcdata_ix = 0; ENTER(E_dax__uses);
 }
	YY_BREAK
case 113:
YY_RULE_SETUP
{
  if (!AX_dax__uses_file) FAIL("Required attribute `file' not set for `uses' element.");
  if (!AX_dax__uses_size) FAIL("Required attribute `size' not set for `uses' element.");
  LEAVE; STag_dax__uses(); dax__pcdata_ix = 0; ETag_dax__uses(); popbuffer(); /* attribute */
  switch (YY_START) {
   case S_dax__job: case S_dax__job_1: case S_dax__job_2: SET(S_dax__job_2); break;
  }
 }
	YY_BREAK
case 114:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of uses element.", yytext[0]);
	YY_BREAK
case 115:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `uses' element start tag.",yytext);
	YY_BREAK
case YY_STATE_EOF(AL_dax__uses):
FAIL("EOF in attribute list of `uses' element.");
	YY_BREAK

case 116:
/* rule 116 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__uses();
  popbuffer(); /* attribute */
  switch (YY_START) {
   case S_dax__job: case S_dax__job_1: case S_dax__job_2: SET(S_dax__job_2); break;
  }
 }
	YY_BREAK
case 117:
/* rule 117 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</uses>' expected.",yytext);
	YY_BREAK
case 118:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</uses>' expected.",yytext[0]);
	YY_BREAK
case YY_STATE_EOF(E_dax__uses):
FAIL("Premature EOF: `</uses>' expected.");
	YY_BREAK

/* EPILOG: after the root element. */

case 119:
YY_RULE_SETUP
{SET(PROLOG); yyless(0); CLEANUP; return -1;}
	YY_BREAK
case YY_STATE_EOF(EPILOG):
SUCCEED;
	YY_BREAK

/* CHARACTER DATA. */

/* Non-defined standard entities... */
case 120:
YY_RULE_SETUP
BUFFERPUTC('&');
	YY_BREAK
case 121:
YY_RULE_SETUP
BUFFERPUTC('<');
	YY_BREAK
case 122:
YY_RULE_SETUP
BUFFERPUTC('>');
	YY_BREAK
case 123:
YY_RULE_SETUP
BUFFERPUTC('\'');
	YY_BREAK
case 124:
YY_RULE_SETUP
BUFFERPUTC('"');
	YY_BREAK
/* Character entities. */
case 125:
YY_RULE_SETUP
BUFFERPUTC((unsigned char)atoi(yytext+2));
	YY_BREAK
case 126:
YY_RULE_SETUP
BUFFERPUTC((unsigned char)strtol(yytext+3,NULL,16));
	YY_BREAK

case 127:
/* rule 127 can match eol */
case 128:
/* rule 128 can match eol */
case 129:
/* rule 129 can match eol */
case 130:
/* rule 130 can match eol */
YY_RULE_SETUP
BUFFERPUTC('\n');
	YY_BREAK

case 131:
YY_RULE_SETUP
ENTER(CDATA);
	YY_BREAK
case 132:
YY_RULE_SETUP
FAIL("Unexpected `]""]>' in character data.");
	YY_BREAK

case 133:
YY_RULE_SETUP
BUFFERDONE; LEAVE;
	YY_BREAK
case YY_STATE_EOF(VALUE1):
FAIL("EOF in literal (\"'\" expected).");
	YY_BREAK

case 134:
YY_RULE_SETUP
BUFFERDONE; LEAVE;
	YY_BREAK
case YY_STATE_EOF(VALUE2):
FAIL("EOF in literal (`\"' expected).");
	YY_BREAK

case 135:
/* rule 135 can match eol */
YY_RULE_SETUP
BUFFERPUTC(yytext[0]);
	YY_BREAK
case 136:
YY_RULE_SETUP
FAIL("Spurious `%c' in character data.",yytext[0]);
	YY_BREAK

case 137:
YY_RULE_SETUP
LEAVE;
	YY_BREAK
/* "]""]"		BUFFERPUTC(yytext[0]); BUFFERPUTC(yytext[1]); */
case 138:
YY_RULE_SETUP
BUFFERPUTC(yytext[0]);
	YY_BREAK
case YY_STATE_EOF(CDATA):
FAIL("EOF in CDATA section.");
	YY_BREAK

/* Impossible rules to avoid warnings from flex(1). */
/* Ideally, this should be replaced by code in flexml.pl that
    generates just the states not covered by other rules. */

case 139:
/* rule 139 can match eol */
YY_RULE_SETUP
FAIL("Syntax error on character `%c'.", yytext[0]);
	YY_BREAK

case 140:
YY_RULE_SETUP
ECHO;
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ROOT_dax__adag):
case YY_STATE_EOF(S_dax__adag_2):
case YY_STATE_EOF(S_dax__adag_4):
case YY_STATE_EOF(S_dax__child_1):
case YY_STATE_EOF(S_dax__job_1):
case YY_STATE_EOF(IMPOSSIBLE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 775 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 775 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 774);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_size_t) (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc( new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc(
					(void *) (yy_start_stack), new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree( (yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

/* Element context stack lookup. */
int dax__element_context(int i)
{
  return (0<i && i<yy_start_stack_depth
	  ? yy_start_stack[yy_start_stack_ptr - i]
	  : 0);
}

#ifdef FLEX_DEBUG
void print_yy_stack(char* fmt, ...)
{
  int i = 0; va_list ap; va_start(ap, fmt);
  vfprintf(stderr, fmt, ap);
  if (dax__statenames) {
      for (i=1; i<yy_start_stack_ptr; i++) {
          fprintf(stderr, "%s/", dax__statenames[yy_start_stack[i] ]);
      }
      fprintf(stderr,"%s\n", dax__statenames[YY_START]);
  }
  va_end(ap);
}

void print_dax__bufferstack()
{
    int i;
    fputs("Buffer: ", stderr);
    for (i = 0; i < blimit; i++) {
       if ( dax__bufferstack[i] == '\377' ) break;
         putc(dax__bufferstack[i], stderr);
    }
    putc('\n', stderr);
}

static void debug_enter(int state, const char* statename) {
  yy_push_state(state);
  if (yy_flex_debug) {
       print_yy_stack("--ENTER(%s) : ",statename);
       print_dax__bufferstack();
  }
}

static void debug_leave(void) {
    if (yy_flex_debug) {
        print_yy_stack("--LEAVE : ");
	print_dax__bufferstack();
    }
  yy_pop_state();
}

static void debug_set(int state, const char* statename) {
  BEGIN(state);
  if (yy_flex_debug) print_yy_stack("--SET(%s) : ",statename);
}
#endif

static void cleanup(void)
{
    if (dax__statenames) {
        free(dax__statenames);
	dax__statenames = NULL;
    }
    free(dax__bufferstack);
    dax__bufferstack = NULL;

    free(indexstack);
    indexstack = NULL;
}

static int fail(const char* fmt, ...)
{
    int chars_left, used;
    va_list ap; va_start(ap, fmt);
#ifdef FLEXML_yylineno
    used = snprintf(flexml_err_msg,flexml_max_err_msg_size,
		   "Invalid XML (XML input line %d, state %d): ",
		   yylineno, YY_START);
#else
    used = snprintf(flexml_err_msg,flexml_max_err_msg_size,
		   "Invalid XML (state %d): ",
		   YY_START);
#endif
    chars_left = flexml_max_err_msg_size - used - 1;
    vsnprintf(flexml_err_msg + used, chars_left, fmt, ap);
    va_end(ap);

#ifndef FLEXML_quiet_parser
    /* print directly to sdterr */
    fprintf(stderr, "%s\n", flexml_err_msg);
    flexml_err_msg[0] = '\0';
#endif

    cleanup();

    return 1;
}

